==> robocorp-dialog-0.2.1.tar.gz: robocorp-dialog-0.2.1/robocorp_dialog/Dialog.app/Contents/MacOS/robocorp_dialog/static/._app.3cdf83ed.js <==
    Mac OS X            	   2  )     )D                                      ATTR      )D  L  '                 L     com.apple.cs.CodeDirectory          com.apple.cs.CodeEntitlements           com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #|  com.apple.cs.CodeSignature                 4       K              Aapp.3cdf83ed 2H9N5J72C7 狷ㄊZe][ȭ-A                                        }UCb0                    | Xl|Pԏ6qq   <?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
  <!--
    These are required for binaries built by PyInstaller.
    For more info, see:
      https://developer.apple.com/documentation/security/hardened_runtime
      https://github.com/pyinstaller/pyinstaller/issues/4629
  -->
  <dict>
    <key>com.apple.security.cs.allow-unsigned-executable-memory</key>
    <true/>
  </dict>
</plist>
                            app.3cdf83ed                  
*Hcd                   
*Hcd
                
subject.OU        
2H9N5J72C7               4       K               Aapp.3cdf83ed 2H9N5J72C7 s FˉQa3}(                                                                 ŞHgߛX;}'4O]                                {m$UPv,1^KU_sJqS~la}:&0	*H
010
	`He 0	*H
  00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00
6#0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
200312215442Z
250313215442Z010
	&,d
2H9N5J72C71K0IUBDeveloper ID Application: RoboCorp Technologies, Inc. (2H9N5J72C7)10U
2H9N5J72C71$0"U
RoboCorp Technologies, Inc.10	UUS0"0
	*H
  0
 "KFv5xb=?y}eY(}*	A&{-iLwiVj~ͩ3f.
K@%//4Y~]2G"(R0poD<>0.h!QE5^"K-gSC>)p6dERz+
=s{_`ĬBjF#N6H>cـطLVFčpw6@H"=!>Uـɖa 00U0 0U#0W|-,T0@+40200+0$http://ocsp.apple.com/ocsp03-devid060U 00	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.06+*http://www.apple.com/certificateauthority/0U%0
+0U!n)f&
[Wߘ:<0U0
*Hcd!20200312000000Z0
*Hcd
 0
	*H
  i`T*Шꌲ 0u:FCD\ҙ.j[nw5)O?.ME$Lf	
Ό xBHT'B`miH|Ȓxu7t`4t#6]GIî՗7
+ޣS3H҅zlۼSam̷l֛eEusw]dW1GܴBda儣 xz1000y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS
6#0
	`He %0	*H
	1	*H
0	*H
	1
210524110030Z0/	*H
	1" aj"9M5_JB#,Q0[	*Hcd	1N0+{MčgsL+/Nę0-	`He Vt+.%+Miif=y#}C0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		e00fxI1n0HOmg8tMKy9OwZ/Emec=
		</data>
		<data>
		VnTG/SupnhzjLiUrG/xNGw6I0mk=
		</data>
	</array>
</dict>
</plist>
0
	*H
  e{E?0OkGJ<Dcq2	\rAr5j;w#0l.gCTՖ\ `A.Qy_$|~mR獙)y)^,?|;4qTpp0ɧOXc.)v&';TXfcn2p{dqQq<I
hFdMN߽Y)<Vhoi%Db+J 1nË#E0*H
	10	*H
010	+ 0z*H
	ki0g*010
	`He  8:qŜ:q10XLDIfcXeKDi20210524110030Z0P> fX

00:;B@0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
210428190502Z
210609190501Z0A10UTimestamp Signer MA210U

Apple Inc.10	UUS0"0
	*H
  0
 hKz_3˛E;RH*zCAFGY[b*,ʷq.@IFi "Hl^ Fԅ`d7c|6l]*/~MXAFM#tj(g
VA9oC@vL@I^O&z$Of0	#.@{V)(Qt58EO.@;ffb#5{ 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0Uw1sʃ|q{{dZCW0U0
	*H
  t`b2sŏZ|샑<A|,FhBt" %80TEz#zgY,p "a+j=1e^ Qw]p@=jdfϜrG0Wwr	 >|
C_<LҪ'bU}Wji0Zɩ㭆tJJ'!/uғKD-g/{1e:Fd21G=x>w.ydwv
=]00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS:;B@0	+ 0	*H
	1
*H
	0	*H
	1
210524110030Z0#	*H
	1듄e&,pW1]-0+*H
	1000>(<_CKkS(E0
	*H
  !b"\GhN27&+25
޽٫੷>RY|xp$P:B ?֠bcbBVY-"y6_3ۙv%yN+Jo2QKs0E^jwVO>wBl[SWNWhdrYGp
NNZg =A\¡Q/;EDƕY      

==> robocorp-dialog-0.2.2.tar.gz: robocorp-dialog-0.2.2/robocorp_dialog/Dialog.app/Contents/MacOS/robocorp_dialog/static/._app.3cdf83ed.js <==
    Mac OS X            	   2  )     )E                                      ATTR      )E  L  '                 L     com.apple.cs.CodeDirectory          com.apple.cs.CodeEntitlements           com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #}  com.apple.cs.CodeSignature                 4       K              Aapp.3cdf83ed 2H9N5J72C7 狷ㄊZe][ȭ-A                                        }UCb0                    | Xl|Pԏ6qq   <?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
  <!--
    These are required for binaries built by PyInstaller.
    For more info, see:
      https://developer.apple.com/documentation/security/hardened_runtime
      https://github.com/pyinstaller/pyinstaller/issues/4629
  -->
  <dict>
    <key>com.apple.security.cs.allow-unsigned-executable-memory</key>
    <true/>
  </dict>
</plist>
                            app.3cdf83ed                  
*Hcd                   
*Hcd
                
subject.OU        
2H9N5J72C7               4       K               Aapp.3cdf83ed 2H9N5J72C7 s FˉQa3}(                                                                 ŞHgߛX;}'4O]                                {m$UPv,1^KU_sJqS~la}:&0	*H
010
	`He 0	*H
  00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00
6#0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
200312215442Z
250313215442Z010
	&,d
2H9N5J72C71K0IUBDeveloper ID Application: RoboCorp Technologies, Inc. (2H9N5J72C7)10U
2H9N5J72C71$0"U
RoboCorp Technologies, Inc.10	UUS0"0
	*H
  0
 "KFv5xb=?y}eY(}*	A&{-iLwiVj~ͩ3f.
K@%//4Y~]2G"(R0poD<>0.h!QE5^"K-gSC>)p6dERz+
=s{_`ĬBjF#N6H>cـطLVFčpw6@H"=!>Uـɖa 00U0 0U#0W|-,T0@+40200+0$http://ocsp.apple.com/ocsp03-devid060U 00	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.06+*http://www.apple.com/certificateauthority/0U%0
+0U!n)f&
[Wߘ:<0U0
*Hcd!20200312000000Z0
*Hcd
 0
	*H
  i`T*Шꌲ 0u:FCD\ҙ.j[nw5)O?.ME$Lf	
Ό xBHT'B`miH|Ȓxu7t`4t#6]GIî՗7
+ޣS3H҅zlۼSam̷l֛eEusw]dW1GܴBda儣 xz1000y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS
6#0
	`He %0	*H
	1	*H
0	*H
	1
210531070947Z0/	*H
	1" aj"9M5_JB#,Q0[	*Hcd	1N0+{MčgsL+/Nę0-	`He Vt+.%+Miif=y#}C0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		e00fxI1n0HOmg8tMKy9OwZ/Emec=
		</data>
		<data>
		VnTG/SupnhzjLiUrG/xNGw6I0mk=
		</data>
	</array>
</dict>
</plist>
0
	*H
  b6°4Բ{]NF^OP߮HOd}Qi:JjM䄓't6D8ɷQ@3]҂y4Hl`JWz{ӗO'sM?z4H"!v,ɳ57e+|b<飁-,Q\$^3z#ٱi(uٴ~f2l1Kv#Rm/lk/ň|uu1Lg^nm'mHA 䅩IGw]y*Y`)ٚd-0*H
	10	*H
010	+ 0{*H
	lj0h*010
	`He  F-{4L}D1mG-z3ddװ20210531070947Z0	 0L$r;"
004G0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
210526190001Z
210707190000Z0A10UTimestamp Signer MA210U

Apple Inc.10	UUS0"0
	*H
  0
 ./grd͊Q17H_N( =P$/
^d.@yЂ+ʧZpŞ}Ɠ4MY~&jfIv"@gۘ3RÛEZ58SܞтQyHL7	hi7fW
{X =vCmFhY$vCP؟(,lV?#Ln9?
@J
ԝ_Z$Vfp22i 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0Uvci:[Iu/0U0
	*H
  mϛ0e$fFcʲW_W~Y>?_G0>j&^,NeӖxx]i{XV̔6j)͐(us>FX_*K^}Sħ'8z,7gֈ[°	kvWi76.{i.м/əT`h!ǿ.H`f60EhDfc0hWz00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS4G0	+ 0	*H
	1
*H
	0	*H
	1
210531070947Z0#	*H
	1jf $U[ZaG0+*H
	1000`hݧj,>Q-	."'m0
	*H
  c
L<U˪;.g0ukLLf^+Y%NFL&S9^tؾ,p2b^11X>@/8)OS-kAX$ᯉn^ߣA<lMeTd463IxuJS4KJNVNRÆaM0̯~ >q7aW f8z|Z?؉3!ԪȜV}ܔ      
